pub fn builtin_named_styles() -> Vec<(String, Style, StyleIncludes)>Expand description
Returns the full list of Excel built-in named styles with their style definitions and the formatting categories each one includes.
pub fn builtin_named_styles() -> Vec<(String, Style, StyleIncludes)>Returns the full list of Excel built-in named styles with their style definitions and the formatting categories each one includes.