CfRuleInput

Enum CfRuleInput 

pub enum CfRuleInput {
Show 18 variants ColorScale { thresholds: Vec<ColorScaleThreshold>, }, CellIs { operator: ValueOperator, formula: String, formula2: Option<String>, format: Dxf, stop_if_true: bool, }, Text { operator: TextOperator, value: String, format: Dxf, stop_if_true: bool, }, Formula { formula: String, format: Dxf, stop_if_true: bool, }, TimePeriod { time_period: PeriodType, date1: Option<String>, date2: Option<String>, format: Dxf, stop_if_true: bool, }, DuplicateValues { format: Dxf, stop_if_true: bool, }, UniqueValues { format: Dxf, stop_if_true: bool, }, Blanks { format: Dxf, stop_if_true: bool, }, NotBlanks { format: Dxf, stop_if_true: bool, }, Errors { format: Dxf, stop_if_true: bool, }, NoErrors { format: Dxf, stop_if_true: bool, }, AboveAverage { format: Dxf, stop_if_true: bool, }, BelowAverage { format: Dxf, stop_if_true: bool, }, Top10 { rank: u32, percent: bool, format: Dxf, stop_if_true: bool, }, Bottom10 { rank: u32, percent: bool, format: Dxf, stop_if_true: bool, }, DataBar { min: Option<Cfvo>, max: Option<Cfvo>, positive_color: Color, negative_color: Color, is_gradient: bool, show_value: bool, }, IconSet { thresholds: Vec<IconThreshold>, show_value: bool, }, IconRating { icon: Icon, color: Color, thresholds: Vec<(Cfvo, bool)>, show_value: bool, },
}
User-facing input type for creating or updating a CF rule. Mirrors CfRule but dxf-based variants carry a Dxf format instead of a dxf_id index. Non-dxf variants (ColorScale, DataBar, IconSet, IconRating) are identical to their CfRule counterparts.

Variants



ColorScale

Fields



CellIs

Fields

operator: ValueOperator
formula: String
formula2: Option<String>
format: Dxf
stop_if_true: bool


Text

Fields

operator: TextOperator
value: String
format: Dxf
stop_if_true: bool


Formula

Fields

formula: String
format: Dxf
stop_if_true: bool


TimePeriod

Fields

time_period: PeriodType
format: Dxf
stop_if_true: bool


DuplicateValues

Fields

format: Dxf
stop_if_true: bool


UniqueValues

Fields

format: Dxf
stop_if_true: bool


Blanks

Fields

format: Dxf
stop_if_true: bool


NotBlanks

Fields

format: Dxf
stop_if_true: bool


Errors

Fields

format: Dxf
stop_if_true: bool


NoErrors

Fields

format: Dxf
stop_if_true: bool


AboveAverage

Fields

format: Dxf
stop_if_true: bool


BelowAverage

Fields

format: Dxf
stop_if_true: bool


Top10

Fields

rank: u32
percent: bool
format: Dxf
stop_if_true: bool


Bottom10

Fields

rank: u32
percent: bool
format: Dxf
stop_if_true: bool


DataBar

Fields

positive_color: Color
negative_color: Color
is_gradient: bool
show_value: bool


IconSet

Fields

thresholds: Vec<IconThreshold>
show_value: bool


IconRating

Fields

icon: Icon
color: Color
thresholds: Vec<(Cfvo, bool)>
show_value: bool