add_implicit_intersection

Function add_implicit_intersection 

pub fn add_implicit_intersection(node: &mut Node, add: bool)
Traverses the formula tree adding the implicit intersection operator in all arguments of functions that expect a scalar but get a range.

  • A:A => @A:A
  • SIN(A1:D1) => SIN(@A1:D1)

Assumes formula return a scalar