to_excel_string

Function to_excel_string 

pub fn to_excel_string(node: &Node, context: &CellReferenceRC) -> String
This is the mode used to export the formula to Excel Internally the locale and language are always “en”