pub struct CompletionContext {
pub expecting: Vec<ExpectedTokens>,
pub replace_from: usize,
}Expand description
What the grammar accepts at a cursor position, plus the span the UI should
replace when it inserts a completion. Returned by Parser::parse_at_cursor.
Fields
expecting: Vec<ExpectedTokens>What the grammar accepts at the cursor.
replace_from: usizeThe span [replace_from, cursor) the UI should replace — e.g. the F
in A1+F. Equals the cursor when there is nothing to replace (right
after SUM().