pub enum Error {
REF,
NAME,
VALUE,
DIV,
NA,
NUM,
ERROR,
NIMPL,
SPILL,
CALC,
CIRC,
NULL,
}Expand description
List of errors
Note that “#ERROR!” and “#N/IMPL!” are not part of the xlsx standard
- “#ERROR!” means there was an error processing the formula (for instance “=A1+”)
- “#N/IMPL!” means the formula or feature in Excel but has not been implemented in IronCalc Note that they are serialized/deserialized by index
Variants
Implementations