Link

Enum Link 

pub enum Link {
    External {
        target: String,
        tooltip: Option<String>,
    },
    Internal {
        location: String,
        tooltip: Option<String>,
    },
}
Represents a hyperlink in the worksheet, which can be either external or internal. The display text is not part of the link, it is the content of the cell the link is attached to. Links are just cell metadata.

Variants



External

A link to a resource outside the workbook: an URL, a mailto: URI or a file. If the target points to a location inside another document it is written as target#location (e.g. file.xlsx#Sheet1!A1).

Fields

target: String
tooltip: Option<String>


Internal

A link to a location in this workbook: a cell reference like Sheet1!A30 or a defined name.

Fields

location: String
tooltip: Option<String>