pub struct DefinedName {
pub name: String,
pub formula: String,
pub sheet_id: Option<u32>,
}Expand description
A defined name. The sheet_id is the sheet index in case the name is local
Fields
name: Stringformula: Stringsheet_id: Option<u32>Trait Implementations
Sourceimpl Clone for DefinedName
impl Clone for DefinedName
Sourcefn clone(&self) -> DefinedName
fn clone(&self) -> DefinedName
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DefinedName
impl Debug for DefinedName
Sourceimpl PartialEq for DefinedName
impl PartialEq for DefinedName
Sourcefn eq(&self, other: &DefinedName) -> bool
fn eq(&self, other: &DefinedName) -> bool
Tests for
self and other values to be equal, and is used by ==.impl<'__de> Decode<'__de> for DefinedNamewhere
'__de:,
impl Encode for DefinedName
impl Eq for DefinedName
impl StructuralPartialEq for DefinedName