pub struct SheetProperties {
pub name: String,
pub state: String,
pub sheet_id: u32,
pub color: Color,
}Expand description
Information need to show a sheet tab in the UI The color is serialized only if it is not Color::None
Fields
name: Stringstate: Stringsheet_id: u32color: ColorTrait Implementations
Sourceimpl Debug for SheetProperties
impl Debug for SheetProperties
Sourceimpl<'de> Deserialize<'de> for SheetProperties
impl<'de> Deserialize<'de> for SheetProperties
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SheetProperties
impl PartialEq for SheetProperties
Sourcefn eq(&self, other: &SheetProperties) -> bool
fn eq(&self, other: &SheetProperties) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SheetProperties
impl Serialize for SheetProperties
impl StructuralPartialEq for SheetProperties