pub struct StyleIncludes {
pub number_format: bool,
pub font: bool,
pub fill: bool,
pub border: bool,
pub alignment: bool,
pub protection: bool,
}Expand description
The formatting categories a named style includes — Excel’s “Style Includes”
checkboxes, stored as the apply* attributes of the style’s cellStyleXfs
record. Applying the style to a cell only stamps the included categories.
The default (like “Normal”) includes everything; the built-in “Percent”,
for example, includes only the number format.
Fields
number_format: boolfont: boolfill: boolborder: boolalignment: boolprotection: boolTrait Implementations
Sourceimpl Clone for StyleIncludes
impl Clone for StyleIncludes
Sourcefn clone(&self) -> StyleIncludes
fn clone(&self) -> StyleIncludes
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StyleIncludes
impl Debug for StyleIncludes
Sourceimpl Default for StyleIncludes
impl Default for StyleIncludes
Sourceimpl<'de> Deserialize<'de> for StyleIncludeswhere
StyleIncludes: Default,
impl<'de> Deserialize<'de> for StyleIncludeswhere
StyleIncludes: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for StyleIncludes
impl PartialEq for StyleIncludes
Sourcefn eq(&self, other: &StyleIncludes) -> bool
fn eq(&self, other: &StyleIncludes) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for StyleIncludes
impl Serialize for StyleIncludes
impl Copy for StyleIncludes
impl<'__de> Decode<'__de> for StyleIncludeswhere
'__de:,
impl Encode for StyleIncludes
impl Eq for StyleIncludes
impl StructuralPartialEq for StyleIncludes