WorksheetView

Struct WorksheetView 

pub struct WorksheetView {
    pub row: i32,
    pub column: i32,
    pub range: [i32; 4],
    pub top_row: i32,
    pub left_column: i32,
}
Represents the state of the worksheet as seen by the user. This includes details such as the currently selected cell, the visible range, and the position of the viewport.

Fields

row: i32

The row index of the currently selected cell.

column: i32

The column index of the currently selected cell.

range: [i32; 4]

The selected range in the worksheet, specified as [start_row, start_column, end_row, end_column].

top_row: i32

The row index of the topmost visible cell in the worksheet view.

left_column: i32

The column index of the leftmost visible cell in the worksheet view.