pub fn to_excel_string(node: &Node, context: &CellReferenceRC) -> StringExpand description
This is the mode used to export the formula to Excel Internally the locale and language are always “en”
pub fn to_excel_string(node: &Node, context: &CellReferenceRC) -> StringThis is the mode used to export the formula to Excel Internally the locale and language are always “en”