pub enum Cell {
EmptyCell {
s: i32,
},
BooleanCell {
v: bool,
s: i32,
},
NumberCell {
v: f64,
s: i32,
},
ErrorCell {
ei: Error,
s: i32,
},
SharedString {
si: i32,
s: i32,
},
CellFormula {
f: i32,
s: i32,
v: FormulaValue,
},
ArrayFormula {
f: i32,
s: i32,
r: (i32, i32),
kind: ArrayKind,
v: FormulaValue,
},
SpillCell {
s: i32,
a: (i32, i32),
v: SpillValue,
},
}Variants
Implementations
Sourceimpl Cell
impl Cell
Sourcepub fn new_string(si: i32, s: i32) -> Cell
pub fn new_string(si: i32, s: i32) -> Cell
Creates a new Cell with a shared string (si is the string index)
Sourcepub fn new_number(v: f64, s: i32) -> Cell
pub fn new_number(v: f64, s: i32) -> Cell
Creates a new Cell with a number
Sourcepub fn new_boolean(v: bool, s: i32) -> Cell
pub fn new_boolean(v: bool, s: i32) -> Cell
Creates a new Cell with a boolean
Sourcepub fn new_formula(f: i32, s: i32) -> Cell
pub fn new_formula(f: i32, s: i32) -> Cell
Creates a new Cell with an unevaluated formula
Sourcepub fn get_formula(&self) -> Option<i32>
pub fn get_formula(&self) -> Option<i32>
Returns the formula index of a cell if any.
pub fn has_formula(&self) -> bool
pub fn set_style(&mut self, style: i32)
pub fn get_style(&self) -> i32
pub fn get_type(&self) -> CellType
pub fn get_localized_text( &self, shared_strings: &[String], locale: &Locale, language: &Language, ) -> String
pub fn value(&self, shared_strings: &[String], language: &Language) -> CellValue
pub fn formatted_value<F>( &self, shared_strings: &[String], language: &Language, format_number: F, ) -> String